
import Link from 'next/link'
import React, { useState, useEffect } from 'react'

import './assets3/css/bootstrap.min.css';
import './assets3/css/animate.min.css';
import './assets3/css/magnific-popup.css';
import './assets3/fontawesome/css/all.min.css';
import './assets3/css/dripicons.css';
import './assets3/css/slick.css';
import './assets3/css/default.css';
import './assets3/css/meanmenu.css';
import './assets3/css/style.css';
import './assets3/css/responsive.css';
import Script from 'next/script';
import Image from 'next/image';

const Home = ({ apiResData }) => {

  const [loading, setLoading] = useState(true);

  const primaryColor = apiResData?.web_primary_color
  const secondaryColor = apiResData?.web_secondary_color


  useEffect(() => {
    if (!loading) {
      document.documentElement.style.setProperty('--white', primaryColor);
      document.documentElement.style.setProperty('--theme', secondaryColor);
    }
  }, [loading, primaryColor, secondaryColor]);

  return (

    <>
      <style jsx global>{`
        :root {
         --white: ${primaryColor};
         --theme: ${secondaryColor};
        }
      `}</style>
      <div>

        {/* header */}
        <header className="header-area">
          <div className="header-top second-header d-none d-md-block">
            <div className="container">
              <div className="row align-items-center">
                <div className="col-lg-6 col-md-8 d-none  d-md-block">
                  <div className="header-cta">
                    <ul>
                      <li>
                        <i className="icon dripicons-mail" />
                        <a href={`mailto:${apiResData?.company_email}`}> {apiResData?.company_email} </a>
                      </li>
                      <li>
                        <i className="icon dripicons-phone" />
                        <a href={`tel:${apiResData?.mobile_number}`}> {apiResData?.mobile_number} </a>
                      </li>
                    </ul>
                  </div>
                </div>
                <div className="col-lg-6 col-md-3 d-none d-lg-block">
                  <div className="header-social text-right">
                    <span>
                      <Link href="#" title="Facebook"><i className="fab fa-facebook" /></Link>
                      <Link href="#" title="Twitter"><i className="fab fa-twitter" /></Link>
                      <Link href="#" title="LinkedIn"><i className="fab fa-linkedin-in" /></Link>
                    </span>
                    {/*  /social media icon redux */}
                  </div>
                </div>
              </div>
            </div>
          </div>
          <div id="header-sticky" className="menu-area menu-area2">
            <div className="container">
              <div className="second-menu">
                <div className="row align-items-center">
                  <div className="col-xl-2 col-lg-2">
                    <div className="logo2">
                      <Link href="/"><img src={apiResData?.logo} alt="logo" style={{ width: '163px' }} /></Link>
                    </div>
                  </div>
                  <div className="col-xl-8 col-lg-8">
                    <div className="main-menu text-right pr-15">
                      <nav id="mobile-menu">
                        <ul>
                          <li><Link href="/">Home</Link></li>
                          <li><Link href="#about">About Us</Link></li>
                          <li><Link href="#services">Services</Link></li>
                          <li><Link href="#plan">Plan</Link></li>
                          <li><Link href="#blog">Blog</Link></li>
                          <li><Link href="#contact">Contact Us</Link></li>
                        </ul>
                      </nav>
                    </div>
                  </div>
                  <div className="col-xl-2 col-lg-2 d-none d-lg-block">
                    <Link href="/login" className="top-btn">Agent Login <i className="fas fa-chevron-right" /></Link>
                  </div>
                  <div className="col-12">
                    <div className="mobile-menu" ></div>
                  </div>
                </div>
              </div>
            </div>
          </div>
        </header >
        {/* header-end */}
        {/* main-area */}
        <main>
          {/* slider-area */}
          <section id="home" className="slider-area fix p-relative">
            <div className="slider-active">
              <div className="single-slider slider-bg d-flex align-items-center" style={{ backgroundImage: 'url(assets/theme3/img/slider/slider_img01.png)' }}>
                <div className="container">
                  <div className="row align-items-center">
                    <div className="col-lg-6">
                      <div className="slider-content s-slider-content text-left">
                        <h2 data-animation="fadeInUp" data-delay=".4s">भारत को आत्मनिर्भर बनाएंगे,<br />हर गाँव डिजिटल सर्विसेज लाएंगे.</h2>
                        <p data-animation="fadeInUp" data-delay=".6s">Be an integral part of digital revolution by serving the nation with rapidly growing, extremely secure and Customers, Retailers and Distributers friendly culture.</p>
                        <div className="slider-btn mt-25">
                          <Link href="/login" className="btn ss-btn" data-animation="fadeInRight" data-delay=".8s">Agent Login <i className="fas fa-chevron-right" /></Link>
                        </div>
                      </div>
                    </div>
                    <div className="col-lg-6">
                    </div>
                  </div>
                </div>
              </div>
              <div className="single-slider slider-bg d-flex align-items-center" style={{ backgroundImage: 'url(/assets/theme3/img/slider/slider_img02.png)' }}>
                <div className="container">
                  <div className="row align-items-center">
                    <div className="col-lg-6">
                      <div className="slider-content s-slider-content text-left">
                        <h2 data-animation="fadeInUp" data-delay=".4s">आइए, आप और हम मिलकर<br /> बनाते हैं डिजिटल भारत</h2>
                        <p data-animation="fadeInUp" data-delay=".6s">Be an integral part of digital revolution by serving the nation with rapidly growing, extremely secure and Customers, Retailers and Distributers friendly culture. Recharge &amp; Bills payment, AePS, Money Transfer, Tour and Travels booking , open a savings bank accounts, and do a lot more.</p>
                        <div className="slider-btn mt-25">
                          <Link href="/login" className="btn ss-btn" data-animation="fadeInRight" data-delay=".8s">Agent Login <i className="fas fa-chevron-right" /></Link>
                        </div>
                      </div>
                    </div>
                    <div className="col-lg-6">
                    </div>
                  </div>
                </div>
              </div>
            </div>
          </section>
          {/* slider-area-end */}
          <div className="row sr-line">
            <div className="col-lg-4 col-md-12">
              <div className="s-single-services text-center">
                <div className="services-icon">
                  <img src="/assets/theme3/img/icon/1.png" alt="img" />
                </div>
                <div className="second-services-content">
                  <h5>Safe And Secure</h5>
                  <p>Our Company is Recognition in startup India program by Govt. of India so it’s Safe and Secure.</p>
                </div>
              </div>
            </div>
            <div className="col-lg-4 col-md-12">
              <div className="s-single-services text-center">
                <div className="services-icon">
                  <img src="/assets/theme3/img/icon/2.png" alt="img" ></img>
                </div>
                <div className="second-services-content">
                  <h5>Esay Integration</h5>
                  <p>Singup and go with easy integration feature for your web and mobile applications.</p>
                </div>
              </div>
            </div>
            <div className="col-lg-4 col-md-12">
              <div className="s-single-services text-center">
                <div className="services-icon">
                  <img src="/assets/theme3/img/icon/3.png" alt="img" />
                </div>
                <div className="second-services-content">
                  <h5>Fast Response</h5>
                  <p>We use Restfull API's which deliver fastest response over requests made from web or mobile devices.</p>
                </div>
              </div>
            </div>
          </div>
          <br />
          <div className="row sr-line">
            <div className="col-lg-4 col-md-12">
              <div className="s-single-services text-center">
                <div className="services-icon">
                  <img src="/assets/theme3/img/icon/4.png" alt="img" />
                </div>
                <div className="second-services-content">
                  <h5>24/7 Support</h5>
                  <p>Our customer service is best in class and commited to serve you 24x7 for your queries and questions.</p>
                </div>
              </div>
            </div>
            <div className="col-lg-4 col-md-12">
              <div className="s-single-services text-center">
                <div className="services-icon">
                  <img src="/assets/theme3/img/icon/5.png" alt="img" />
                </div>
                <div className="second-services-content">
                  <h5>All Platform</h5>
                  <p>No worries of technology or platform your application is built on we support all of them.</p>
                </div>
              </div>
            </div>
            <div className="col-lg-4 col-md-12">
              <div className="s-single-services text-center">
                <div className="services-icon">
                  <img src="/assets/theme3/img/icon/6.png" alt="img" />
                </div>
                <div className="second-services-content">
                  <h5>High Commission</h5>
                  <p>We are Provide Heights commission and Margins for all Agents in over india.</p>
                </div>
              </div>
            </div>
          </div>
          {/* about-area */}
          <section id="about" className="about-area about-p mt-100 pb-80 p-relative" style={{ backgroundImage: 'url(/assets/theme3/img/an-bg/an-bg03.png)', backgroundSize: 'contain', backgroundRepeat: 'no-repeat', backgroundPosition: 'center center' }}>
            <div className="container">
              <div className="row align-items-center">
                <div className="col-lg-6 col-md-12 col-sm-12">
                  <div className="single-counter-img fadeInUp animated">
                    <img src="/assets/theme3/img/benifitstapir.png" alt="img" />
                  </div>
                </div>
                <div className="col-lg-6 col-md-12 col-sm-12">
                  <div className="about-content s-about-content pl-30">
                    <div className="section-title mb-20">
                      <span>About Us</span>
                      <h2>We Believe That Quality Of Services Matters</h2>
                    </div>
                    <p>Better Services Provide by world's best leading online service provider in India. We at UdayPayprovide Aadhaar Enabled Payment System (AEPS), Domestic Money Transfer, Recharge (Mobile, Dth, Data Card), Bill Payment System (Electricity, Landline, Mobile Bill Payment) of all leading service provider at unbel ievably lowest price. </p>
                    <ul>
                      <li>
                        <div className="icon"><i className="fas fa-chevron-right" /></div>
                        <div className="text">Safe And Secure.
                        </div>
                      </li>
                      <li>
                        <div className="icon"><i className="fas fa-chevron-right" /></div>
                        <div className="text">Esay Integration.
                        </div>
                      </li>
                      <li>
                        <div className="icon"><i className="fas fa-chevron-right" /></div>
                        <div className="text">24/7 Support.
                        </div>
                      </li>
                      <div />
                    </ul>
                    <div className="slider-btn mt-30">
                      <Link href="#" className="btn ss-btn" data-animation="fadeInRight" data-delay=".8s">Read More <i className="fas fa-chevron-right" /></Link>
                    </div>
                  </div>
                </div>
              </div>
            </div>
          </section>
          {/* about-area-end */}
          {/* services-area */}
          <section id="services" className="services-area services-bg services-two pt-20 pb-55" style={{ backgroundImage: 'url(/assets/theme3/img/an-bg/an-bg02.png)', backgroundSize: 'contain', backgroundRepeat: 'no-repeat', backgroundPosition: 'center center' }}>
            <div className="container">
              <div className="row justify-content-center">
                <div className="col-xl-8 col-lg-8">
                  <div className="section-title text-center pl-40 pr-40 mb-80">
                    <span> our services</span>
                    <h2>Benifits Of Our Services</h2>
                    <p className="mt-10">All the banking and digital services provided by us are fully secured. You can help your customers with easy digital money transfers, payments, and other banking facilities.</p>
                  </div>
                </div>
              </div>
              <div className="container">
                <div className="row align-items-end">
                  <div className="col-lg-3 col-md-6 col-sm-12">
                    <div className="single-counter text-center">
                      <img src="/assets/theme3/img/services/1.png" alt="img" />
                      <p>AEPS Services</p>
                    </div>
                  </div>
                  <div className="col-lg-3 col-md-6 col-sm-12">
                    <div className="single-counter text-center">
                      <img src="/assets/theme3/img/services/2.png" alt="img" />
                      <p>Aadhar Pay</p>
                    </div>
                  </div>
                  <div className="col-lg-3 col-md-6 col-sm-12">
                    <div className="single-counter text-center">
                      <img src="/assets/theme3/img/services/3.png" alt="img" />
                      <p>Money Transfer</p>
                    </div>
                  </div>
                  <div className="col-lg-3 col-md-6 col-sm-12">
                    <div className="single-counter text-center">
                      <img src="/assets/theme3/img/services/4.png" alt="img" />
                      <p>Mini ATM</p>
                    </div>
                  </div>
                </div>
              </div>
              <br />
              <div className="container">
                <div className="row align-items-end">
                  <div className="col-lg-3 col-md-6 col-sm-12">
                    <div className="single-counter text-center">
                      <img src="/assets/theme3/img/services/5.png" alt="img" />
                      <p>Insurance</p>
                    </div>
                  </div>
                  <div className="col-lg-3 col-md-6 col-sm-12">
                    <div className="single-counter text-center">
                      <img src="/assets/theme3/img/services/6.png" alt="img" />
                      <p>CMS</p>
                    </div>
                  </div>
                  <div className="col-lg-3 col-md-6 col-sm-12">
                    <div className="single-counter text-center">
                      <img src="/assets/theme3/img/services/7.png" alt="img" />
                      <p>Mini Statement</p>
                    </div>
                  </div>
                  <div className="col-lg-3 col-md-6 col-sm-12">
                    <div className="single-counter text-center">
                      <img src="/assets/theme3/img/services/8.png" alt="img" />
                      <p>Open Bank Account</p>
                    </div>
                  </div>
                </div>
              </div>
            </div>
          </section>
          {/* services-area-end */}
          {/* department-area */}
          <section className="department-area cta-bg pb-70 mt-10 fix" style={{ backgroundImage: 'url(/assets/theme3/img/an-bg/an-bg05.png)', backgroundSize: 'contain' }}>
            <div className="container">
              <div className="row align-items-center">
                <div className="col-lg-6">
                  <div className="section-title mb-50  ">
                    <span>OUR DEPARTMENTS</span>
                    <h2>Banking And Financial Services</h2>
                  </div>
                  <ul>
                    <li>
                      <div className="icon">
                        <div><img src="/assets/theme3/img/services/9.png" alt="de-icon" /></div></div>
                      <Link href="#" className="text">
                        <h3>Quick Bank Account Balance Enquiry</h3>
                      </Link>
                    </li>
                    <li className="active">
                      <div className="icon">
                        <div><img src="/assets/theme3/img/services/10.png" alt="de-icon" /></div></div>
                      <Link href="#" className="text">
                        <h3>Bank Mini Statement for Customers</h3>
                      </Link>
                    </li>
                    <li>
                      <div className="icon">
                        <div><img src="/assets/theme3/img/services/11.png" alt="de-icon" /></div></div>
                      <Link href="#" className="text">
                        <h3>Aadhaar Seeding</h3>
                      </Link>
                    </li>
                  </ul>
                </div>
                <div className="col-lg-6">
                  <div className="single-counter-img fadeInUp animated">
                    <img src="/assets/theme3/img/servicesbanner.png" alt="img" />
                  </div>
                </div>
              </div>
              <div className="container">
                <div className="row align-items-end">
                  <div className="col-lg-3 col-md-6 col-sm-12">
                    <div className="single-counter text-center">
                      <img src="/assets/theme3/img/services/12.png" alt="img" />
                      <p>Prepaid &amp; Postpaid</p>
                    </div>
                  </div>
                  <div className="col-lg-3 col-md-6 col-sm-12">
                    <div className="single-counter text-center">
                      <img src="/assets/theme3/img/services/13.png" alt="img" />
                      <p>Electricity Bill</p>
                    </div>
                  </div>
                  <div className="col-lg-3 col-md-6 col-sm-12">
                    <div className="single-counter text-center">
                      <img src="/assets/theme3/img/services/14.png" alt="img" />
                      <p>DTH &amp; Data Card</p>
                    </div>
                  </div>
                  <div className="col-lg-3 col-md-6 col-sm-12">
                    <div className="single-counter text-center">
                      <img src="/assets/theme3/img/services/15.png" alt="img" />
                      <p>Gas Booking</p>
                    </div>
                  </div>
                </div>
              </div>
              <br />
              <div className="container">
                <div className="row align-items-end">
                  <div className="col-lg-3 col-md-6 col-sm-12">
                    <div className="single-counter text-center">
                      <img src="/assets/theme3/img/services/16.png" alt="img" />
                      <p>Broadband &amp; Landlines</p>
                    </div>
                  </div>
                  <div className="col-lg-3 col-md-6 col-sm-12">
                    <div className="single-counter text-center">
                      <img src="/assets/theme3/img/services/17.png" alt="img" />
                      <p>Credit Card</p>
                    </div>
                  </div>
                  <div className="col-lg-3 col-md-6 col-sm-12">
                    <div className="single-counter text-center">
                      <img src="/assets/theme3/img/services/18.png" alt="img" />
                      <p>Water Bill</p>
                    </div>
                  </div>
                  <div className="col-lg-3 col-md-6 col-sm-12">
                    <div className="single-counter text-center">
                      <img src="/assets/theme3/img/services/19.png" alt="img" />
                      <p>BBPS</p>
                    </div>
                  </div>
                </div>
              </div>
            </div>
          </section>
          {/* department-area-end */}
          {/* counter-area */}
          <div className="call-area pb-50" style={{ backgroundImage: 'url(/assets/theme3/img/an-bg/an-bg09.png)', backgroundRepeat: 'no-repeat', backgroundPosition: 'bottom' }}>
            <div className="container">
              <div className="row align-items-center">
                <div className="col-lg-5 col-md-12 col-sm-12">
                  <div className="single-counter-img fadeInUp animated">
                    <img src="/assets/theme3/img/tapirtemeban.png" alt="img" className="img" />
                  </div>
                </div>
                <div className="col-lg-5 col-md-12 col-sm-12">
                  <div className="section-title mt-100">
                    <span>With Us</span>
                    <h3>Get Started with India's No. 1 AePS Service Provider Company</h3>
                  </div>
                </div>
                <div className="col-lg-2 col-md-12 col-sm-12">
                  <div className="slider-btn mt-130">
                    <Link href="#" className="btn ss-btn" data-animation="fadeInRight" data-delay=".8s">Start Now <i className="fas fa-chevron-right" /></Link>
                  </div>
                </div>
              </div>
            </div>
          </div>
          {/* counter-area-end */}
          {/* brand-area */}
          <div className="brand-area" style={{ backgroundImage: 'url(/assets/theme3/img/an-bg/an-bg12.png)', backgroundSize: 'cover', backgroundRepeat: 'no-repeat' }}>
            <div className="container">
              <div className="row brand-active">
                <div className="col-xl-2">
                  <div className="single-brand">
                    <img src="/assets/theme3/img/brand/pay01.png" alt="img" />
                  </div>
                </div>
                <div className="col-xl-2">
                  <div className="single-brand">
                    <img src="/assets/theme3/img/brand/pay02.png" alt="img" />
                  </div>
                </div>
                <div className="col-xl-2">
                  <div className="single-brand">
                    <img src="/assets/theme3/img/brand/pay03.png" alt="img" />
                  </div>
                </div>
                <div className="col-xl-2">
                  <div className="single-brand">
                    <img src="/assets/theme3/img/brand/pay04.png" alt="img" />
                  </div>
                </div>
                <div className="col-xl-2">
                  <div className="single-brand">
                    <img src="/assets/theme3/img/brand/pay05.png" alt="img" />
                  </div>
                </div>
                <div className="col-xl-2">
                  <div className="single-brand">
                    <img src="/assets/theme3/img/brand/pay06.png" alt="img" />
                  </div>
                </div>
                <div className="col-xl-2">
                  <div className="single-brand">
                    <img src="/assets/theme3/img/brand/pay07.png" alt="img" />
                  </div>
                </div>
              </div>
            </div>
          </div>
          {/* brand-area-end */}
          {/* pricing-area */}
          <section id="plan" className="pricing-area pb-70" style={{ backgroundImage: 'url(/assets/theme3/img/an-bg/an-bg08.png)', backgroundPosition: 'center', backgroundRepeat: 'no-repeat' }}>
            <div className="container">
              <div className="row justify-content-center">
                <div className="col-lg-8">
                  <div className="section-title center-align mb-60 text-center">
                    <span>OUR PRICING</span>
                    <h2>Afforable Pricing Packages</h2>
                    <p>Fusce pharetra odio in urna laoreet laoreet. Aliquam erat volutpat. Phasellus nec ligula arcu. Aliquam eu urna pulvinar, iaculis ipsum in, porta massa.</p>
                  </div>
                </div>
              </div>
              <div className="row">
                <div className="col-lg-4 col-md-12">
                  <div className="pricing-box text-center mb-60">
                    <div className="pricing-head">
                      <h4>Sliver Plan</h4>
                    </div>
                    <div className="pricing-body mb-40 text-left">
                      <ul>
                        <li>Normal Commission</li>
                        <li>Email Support</li>
                        <li>Normal Support</li>
                        <li>Limited Features</li>
                        <li>Single Pipeline</li>
                        <li>No Notification</li>
                        <li>Normal Print</li>
                        <li>Single Bank Payout Add</li>
                        <li>No Marketing Material</li>
                        <li>Single device Access</li>
                        <li>No Certificate</li>
                      </ul>
                    </div>
                    <div className="pricing-btn">
                      <Link href="/login" className="btn">Choose Plan <i className="fas fa-chevron-right" /></Link>
                    </div>
                  </div>
                </div>
                <div className="col-lg-4 col-md-12">
                  <div className="pricing-box active text-center mb-60">
                    <div className="pricing-head">
                      <h4>Gold Plan</h4>
                    </div>
                    <div className="pricing-body mb-40 text-left">
                      <ul>
                        <li>10% Extra Commission</li>
                        <li>Email &amp; Call Support</li>
                        <li>Dedicated Support</li>
                        <li>Additional Features</li>
                        <li>Double Pipeline</li>
                        <li>Email Notification</li>
                        <li>Normal &amp; thermal Print</li>
                        <li>Double Bank Payout Add</li>
                        <li>Digital Marketing Material</li>
                        <li>Double device Access</li>
                        <li>Digital Certificate</li>
                      </ul>
                    </div>
                    <div className="pricing-btn">
                      <Link href="/login" className="btn">Choose Plan <i className="fas fa-chevron-right" /></Link>
                    </div>
                  </div>
                </div>
                <div className="col-lg-4 col-md-12">
                  <div className="pricing-box text-center mb-60">
                    <div className="pricing-head">
                      <h4>Diamond Plan</h4>
                    </div>
                    <div className="pricing-body mb-40 text-left">
                      <ul>
                        <li>30% Extra Commission</li>
                        <li>Priority Relationship Manager</li>
                        <li>Priority Support</li>
                        <li>Full Features</li>
                        <li>Multi Pipeline</li>
                        <li>Email Notification</li>
                        <li>Normal &amp; thermal Print</li>
                        <li>Multi Bank Payout Add</li>
                        <li>Physical Marketing Material</li>
                        <li>Multi device Access</li>
                        <li>Physical Certificate</li>
                      </ul>
                    </div>
                    <div className="pricing-btn">
                      <Link href="/login" className="btn">Choose Plan <i className="fas fa-chevron-right" /></Link>
                    </div>
                  </div>
                </div>
              </div>
            </div>
          </section>
          {/* pricing-area-end */}
          {/* blog-area */}
          <section id="blog" className="blog-area  p-relative pt-100 pb-90 fix" style={{ backgroundImage: 'url(/assets/theme3/img/an-bg/an-bg10.png)', backgroundSize: 'contain', backgroundRepeat: 'no-repeat', backgroundPosition: 'center center' }}>
            <div className="container">
              <div className="row justify-content-center">
                <div className="col-xl-8 col-lg-10">
                  <div className="section-title text-center mb-80">
                    <span> OUR LATEST BOLG </span>
                    <h2>Stay Updated To Our Blog &amp; News</h2>
                    <p>Fusce pharetra odio in urna laoreet laoreet. Aliquam erat volutpat. Phasellus nec ligula arcu. Aliquam eu urna pulvinar, iaculis ipsum in, porta massa.</p>
                  </div>
                </div>
              </div>
              <div className="row">
                <div className="col-lg-4 col-md-12">
                  <div className="single-post mb-30">
                    <div className="blog-thumb">
                      <img src="/assets/theme3/img/blog/01.jpg" alt="img" />
                    </div>
                    <div className="blog-content text-center">
                      <h4>Aadhaar Enabled Payment System.</h4>
                    </div>
                  </div>
                </div>
                <div className="col-lg-4 col-md-12">
                  <div className="single-post mb-30">
                    <div className="blog-thumb">
                      <img src="/assets/theme3/img/blog/02.jpg" alt="img" />
                    </div>
                    <div className="blog-content text-center">
                      <h4>Aadhaar Card Centre Online.</h4>
                    </div>
                  </div>
                </div>
                <div className="col-lg-4 col-md-12">
                  <div className="single-post mb-30">
                    <div className="blog-thumb">
                      <img src="/assets/theme3/img/blog/03.jpg" alt="img" />
                    </div>
                    <div className="blog-content text-center">
                      <h4>Bank of Baroda BC Point.</h4>
                    </div>
                  </div>
                </div>
              </div>
            </div>
          </section>
          {/* blog-area-end */}
        </main>
        {/* main-area-end */}
        {/* footer */}
        <footer id="contact" className="footer-bg footer-p">
          <div className="overly"><img src="/assets/theme3/img/an-bg/footer-bg.png" alt="rest" /></div>
          <div className="footer-top pb-30" style={{ backgroundColor: '#ECF1FA' }}>
            <div className="container">
              <div className="row justify-content-between">
                <div className="col-xl-3 col-lg-3 col-sm-6">
                  <div className="footer-widget mb-30">
                    <div className="flog mb-35">
                      <Link href="#"><img src={apiResData?.logo} alt="logo" /></Link>
                    </div>
                    <div className="footer-text mb-20">
                      <p>{apiResData?.about}</p>
                    </div>
                    <div className="footer-social">
                      <Link href="#"><i className="fab fa-facebook-f" /></Link>
                      <Link href="#"><i className="fab fa-twitter" /></Link>
                      <Link href="#"><i className="fab fa-instagram" /></Link>
                      <Link href="#"><i className="fab fa-google-plus-g" /></Link>
                    </div>
                  </div>
                </div>
                <div className="col-xl-2 col-lg-2 col-sm-6">
                  <div className="footer-widget mb-30">
                    <div className="f-widget-title">
                      <h5>Quick Links</h5>
                    </div>
                    <div className="footer-link">
                      <ul>
                        <li><Link href="#"><i className="fas fa-chevron-right" />Home</Link></li>
                        <li><Link href="#about"><i className="fas fa-chevron-right" />About Us</Link></li>
                        <li><Link href="#plan"><i className="fas fa-chevron-right" />Pricing</Link></li>
                        <li><Link href="#"><i className="fas fa-chevron-right" />Privacy Policy</Link></li>
                        <li><Link href="#"><i className="fas fa-chevron-right" /> Terms &amp; Conditions</Link></li>
                        <li><Link href="#contact"><i className="fas fa-chevron-right" /> Contact Us</Link></li>
                      </ul>
                    </div>
                  </div>
                </div>
                <div className="col-xl-2 col-lg-2 col-sm-6">
                  <div className="footer-widget mb-30">
                    <div className="f-widget-title">
                      <h5>Other Links</h5>
                    </div>
                    <div className="footer-link">
                      <ul>
                        <li><Link href="#"><i className="fas fa-chevron-right" />Bill Payment</Link></li>
                        <li><Link href="#"><i className="fas fa-chevron-right" /> Money Transfer</Link></li>
                        <li><Link href="#"><i className="fas fa-chevron-right" /> Aadhaar Payments</Link></li>
                        <li><Link href="#"><i className="fas fa-chevron-right" /> Micro ATM</Link></li>
                        <li><Link href="#"><i className="fas fa-chevron-right" /> PAN Card</Link></li>
                        <li><Link href="#"><i className="fas fa-chevron-right" /> Latest Blog</Link></li>
                      </ul>
                    </div>
                  </div>
                </div>
                <div className="col-xl-3 col-lg-3 col-sm-6">
                  <div className="footer-widget mb-30">
                    <div className="f-widget-title">
                      <h5>Contact Us</h5>
                    </div>
                    <div className="footer-link">
                      <div className="f-contact">
                        <ul>
                          <li>
                            <i className="icon dripicons-phone" />
                            <span> <a href={`tel:${apiResData?.mobile_number}`}> {apiResData?.mobile_number} </a></span>
                          </li>
                          <li>
                            <i className="icon dripicons-mail" />
                            <span><a href={`mailto:${apiResData?.company_email}`}> {apiResData?.company_email} </a></span>
                          </li>
                          <li>
                            <i className="fal fa-map-marker-alt" style={{ width: "90px" }} />
                            <span className='text-wrap'><Link href=""> {apiResData?.company_address} </Link></span>
                          </li>
                        </ul>
                      </div>
                    </div>
                  </div>
                </div>
              </div>
            </div>
          </div>
          <div className="copyright-wrap">
            <div className="container">
              <div className="row">
                <div className="col-12">
                  <div className="copyright-text text-center">
                    {
                      apiResData && apiResData?.design_developed_link ?

                        <p>© 2024 All Copyrights Reserved. <a href={apiResData?.design_developed_link}>({apiResData?.design_developed})</a></p>

                        : null
                    }

                  </div>
                </div>
              </div>
            </div>
          </div>
        </footer>
        {/* footer-end */}
        {/* JS here */}
        {/* JS here */}
      </div >

      {/* Modernizr (load early) */}
      < Script src="/assets/theme3/js/vendor/modernizr-3.5.0.min.js" strategy="beforeInteractive" />

      {/* Load jQuery and Bootstrap early but after the page is interactive */}
      <Script src="/assets/theme3/js/vendor/jquery-1.12.4.min.js" strategy="afterInteractive" />
      <Script src="/assets/theme3/js/popper.min.js" strategy="afterInteractive" />
      <Script src="/assets/theme3/js/bootstrap.min.js" strategy="afterInteractive" />

      {/* Other scripts that depend on jQuery, loaded lazily */}
      <Script src="/assets/theme3/js/one-page-nav-min.js" strategy="lazyOnload" />
      <Script src="/assets/theme3/js/jquery.meanmenu.min.js" strategy="lazyOnload" />
      <Script src="/assets/theme3/js/slick.min.js" strategy="lazyOnload" />
      <Script src="/assets/theme3/js/ajax-form.js" strategy="lazyOnload" />
      <Script src="/assets/theme3/js/paroller.js" strategy="lazyOnload" />
      <Script src="/assets/theme3/js/wow.min.js" strategy="lazyOnload" />
      <Script src="/assets/theme3/js/js_isotope.pkgd.min.js" strategy="lazyOnload" />
      <Script src="/assets/theme3/js/imagesloaded.min.js" strategy="lazyOnload" />
      <Script src="/assets/theme3/js/parallax.min.js" strategy="lazyOnload" />
      <Script src="/assets/theme3/js/jquery.waypoints.min.js" strategy="lazyOnload" />
      <Script src="/assets/theme3/js/jquery.counterup.min.js" strategy="lazyOnload" />
      <Script src="/assets/theme3/js/jquery.scrollUp.min.js" strategy="lazyOnload" />
      <Script src="/assets/theme3/js/parallax-scroll.js" strategy="lazyOnload" />
      <Script src="/assets/theme3/js/jquery.magnific-popup.min.js" strategy="lazyOnload" />
      <Script src="/assets/theme3/js/element-in-view.js" strategy="lazyOnload" />

      {/* Main JS (typically loaded at the end) */}
      <Script src="/assets/theme3/js/main.js" strategy="lazyOnload" />
    </>


  )
}

export default Home
